@@ -49,20 +49,16 @@ public:
   std::string raster_prefix;
   int img_id;
 
-  std::string fontname_serif;
-  std::string fontname_sans;
-  std::string fontname_mono;
-  std::string fontname_symbol;
+  Rcpp::List system_aliases;
+  Rcpp::List user_aliases;
+
   bool editable;
   int standalone;
   XPtrCairoContext cc;
   clipper *clp;
 
   XLSX_dev(std::string filename_,
-           std::string fontname_serif_,
-           std::string fontname_sans_,
-           std::string fontname_mono_,
-           std::string fontname_symbol_,
+           Rcpp::List& aliases_,
            bool editable_, double offx_, double offy_ , int id_,
            std::string raster_prefix_,
            int next_rels_id_, int standalone_,
@@ -72,10 +68,8 @@ public:
 	    id(id_),
 	    offx(offx_), offy(offy_),
 	    raster_prefix(raster_prefix_), img_id(next_rels_id_),
-	    fontname_serif(fontname_serif_),
-	    fontname_sans(fontname_sans_),
-	    fontname_mono(fontname_mono_),
-	    fontname_symbol(fontname_symbol_),
+	    system_aliases(Rcpp::wrap(aliases_["system"])),
+	    user_aliases(Rcpp::wrap(aliases_["user"])),
 	    editable(editable_),
 	    standalone(standalone_),
       cc(gdtools::context_create()){
@@ -133,9 +127,7 @@ void write_t_xlsx(pDevDesc dev, const char* text) {
 void write_text_body_xlsx(pDevDesc dd, R_GE_gcontext *gc, const char* text, double hadj, double fontsize, double fontheight) {
   XLSX_dev *xlsx_obj = (XLSX_dev *) dd->deviceSpecific;
   ppr a_ppr_(hadj, fontsize);
-  std::string fontname_ = fontname(gc->fontfamily, gc->fontface,
-    xlsx_obj->fontname_serif, xlsx_obj->fontname_sans,
-    xlsx_obj->fontname_mono, xlsx_obj->fontname_symbol);
+  std::string fontname_ = fontname(gc->fontfamily, gc->fontface, xlsx_obj->system_aliases, xlsx_obj->user_aliases);
 
   rpr rpr_(fontsize, is_italic(gc->fontface), is_bold(gc->fontface), gc->col, fontname_);
 
@@ -165,13 +157,11 @@ static void xlsx_metric_info(int c, const pGEcontext gc, double* ascent,
     str[1] = '\0';
   }
 
-  std::string fn = fontname(gc->fontfamily, gc->fontface,
-           xlsx_obj->fontname_serif, xlsx_obj->fontname_sans,
-           xlsx_obj->fontname_mono, xlsx_obj->fontname_symbol);
-
-  gdtools::context_set_font(xlsx_obj->cc, fn,
-    gc->cex * gc->ps, is_bold(gc->fontface), is_italic(gc->fontface));
+  std::string file = fontfile(gc->fontfamily, gc->fontface, xlsx_obj->user_aliases);
+  std::string name = fontname(gc->fontfamily, gc->fontface, xlsx_obj->system_aliases, xlsx_obj->user_aliases);
+  gdtools::context_set_font(xlsx_obj->cc, name, gc->cex * gc->ps, is_bold(gc->fontface), is_italic(gc->fontface), file);
   FontMetric fm = gdtools::context_extents(xlsx_obj->cc, std::string(str));
+
   *ascent = fm.ascent;
   *descent = fm.descent;
   *width = fm.width;
@@ -198,12 +188,9 @@ static void xlsx_close(pDevDesc dd) {
 static double xlsx_strwidth(const char *str, const pGEcontext gc, pDevDesc dd) {
   XLSX_dev *xlsx_obj = (XLSX_dev*) dd->deviceSpecific;
 
-  std::string fn = fontname(gc->fontfamily, gc->fontface,
-                            xlsx_obj->fontname_serif, xlsx_obj->fontname_sans,
-                            xlsx_obj->fontname_mono, xlsx_obj->fontname_symbol);
-
-  gdtools::context_set_font(xlsx_obj->cc, fn,
-                            gc->cex * gc->ps, is_bold(gc->fontface), is_italic(gc->fontface));
+  std::string file = fontfile(gc->fontfamily, gc->fontface, xlsx_obj->user_aliases);
+  std::string name = fontname(gc->fontfamily, gc->fontface, xlsx_obj->system_aliases, xlsx_obj->user_aliases);
+  gdtools::context_set_font(xlsx_obj->cc, name, gc->cex * gc->ps, is_bold(gc->fontface), is_italic(gc->fontface), file);
   FontMetric fm = gdtools::context_extents(xlsx_obj->cc, std::string(str));
 
   return fm.width;
@@ -212,14 +199,12 @@ static double xlsx_strwidth(const char *str, const pGEcontext gc, pDevDesc dd) {
 
 static double xlsx_strheight(const char *str, const pGEcontext gc, pDevDesc dd) {
   XLSX_dev *xlsx_obj = (XLSX_dev*) dd->deviceSpecific;
-  std::string fn = fontname(gc->fontfamily, gc->fontface,
-                            xlsx_obj->fontname_serif, xlsx_obj->fontname_sans,
-                            xlsx_obj->fontname_mono, xlsx_obj->fontname_symbol);
 
-  gdtools::context_set_font(xlsx_obj->cc, fn,
-                            gc->cex * gc->ps, is_bold(gc->fontface), is_italic(gc->fontface));
+  std::string file = fontfile(gc->fontfamily, gc->fontface, xlsx_obj->user_aliases);
+  std::string name = fontname(gc->fontfamily, gc->fontface, xlsx_obj->system_aliases, xlsx_obj->user_aliases);
+  gdtools::context_set_font(xlsx_obj->cc, name, gc->cex * gc->ps, is_bold(gc->fontface), is_italic(gc->fontface), file);
   FontMetric fm = gdtools::context_extents(xlsx_obj->cc, std::string(str));
-  // Rprintf( "%s : ascent %.3f descent %.3f height %.3f width  %.3f\n", str, fm.ascent, fm.descent, fm.height, fm.width);
+
   return fm.height;
 }
 
@@ -527,10 +512,7 @@ static void xlsx_new_page(const pGEcontext gc, pDevDesc dd) {
 pDevDesc xlsx_driver_new(std::string filename, int bg, double width, double height,
                          double offx, double offy,
                         int pointsize,
-                        std::string fontname_serif,
-                        std::string fontname_sans,
-                        std::string fontname_mono,
-                        std::string fontname_symbol,
+                        Rcpp::List aliases,
                         bool editable, int id,
                         std::string raster_prefix,
                         int next_rels_id,
@@ -600,8 +582,8 @@ pDevDesc xlsx_driver_new(std::string filename, int bg, double width, double heig
   dd->haveTransparentBg = 2;
 
   dd->deviceSpecific = new XLSX_dev(filename,
-    fontname_serif, fontname_sans, fontname_mono, fontname_symbol,
-    editable, offx*72, offy*72, id,
+                                    aliases,
+                                    editable, offx*72, offy*72, id,
     raster_prefix,
     next_rels_id, standalone,
     width * 72,
@@ -614,10 +596,7 @@ pDevDesc xlsx_driver_new(std::string filename, int bg, double width, double heig
 bool XLSX_(std::string file, std::string bg_, double width, double height,
     double offx, double offy,
     int pointsize,
-    std::string fontname_serif,
-    std::string fontname_sans,
-    std::string fontname_mono,
-    std::string fontname_symbol,
+    Rcpp::List aliases,
     bool editable, int id,
     std::string raster_prefix,
     int next_rels_id, int standalone) {
@@ -628,8 +607,8 @@ bool XLSX_(std::string file, std::string bg_, double width, double height,
   R_CheckDeviceAvailable();
   BEGIN_SUSPEND_INTERRUPTS {
     pDevDesc dev = xlsx_driver_new(file, bg, width, height, offx, offy, pointsize,
-      fontname_serif, fontname_sans, fontname_mono, fontname_symbol,
-      editable,
+                                   aliases,
+                                   editable,
       id,
       raster_prefix,
       next_rels_id, standalone);
